pub struct EventPage {
pub events: Vec<StoredEvent>,
pub next_cursor: Option<EventId>,
}Expand description
Page of events plus the cursor needed to continue reading.
Fields
events: Vec<StoredEvent>next_cursor: Option<EventId>Inclusive from_event_id to pass into the next read to resume.
None when the requested range was fully drained.